# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class Event(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'alert_tags': 'list[str]',
        'annotations': 'dict(str, str)',
        'can_close': 'bool',
        'can_delete': 'bool',
        'created_at': 'int',
        'created_epoch_millis': 'int',
        'creator_id': 'str',
        'creator_type': 'list[str]',
        'dimensions': 'dict(str, list[str])',
        'end_time': 'int',
        'hosts': 'list[str]',
        'id': 'str',
        'is_ephemeral': 'bool',
        'is_user_event': 'bool',
        'metrics_used': 'list[str]',
        'name': 'str',
        'running_state': 'str',
        'start_time': 'int',
        'summarized_events': 'int',
        'table': 'str',
        'tags': 'list[str]',
        'updated_at': 'int',
        'updated_epoch_millis': 'int',
        'updater_id': 'str'
    }

    attribute_map = {
        'alert_tags': 'alertTags',
        'annotations': 'annotations',
        'can_close': 'canClose',
        'can_delete': 'canDelete',
        'created_at': 'createdAt',
        'created_epoch_millis': 'createdEpochMillis',
        'creator_id': 'creatorId',
        'creator_type': 'creatorType',
        'dimensions': 'dimensions',
        'end_time': 'endTime',
        'hosts': 'hosts',
        'id': 'id',
        'is_ephemeral': 'isEphemeral',
        'is_user_event': 'isUserEvent',
        'metrics_used': 'metricsUsed',
        'name': 'name',
        'running_state': 'runningState',
        'start_time': 'startTime',
        'summarized_events': 'summarizedEvents',
        'table': 'table',
        'tags': 'tags',
        'updated_at': 'updatedAt',
        'updated_epoch_millis': 'updatedEpochMillis',
        'updater_id': 'updaterId'
    }

    def __init__(self, alert_tags=None, annotations=None, can_close=None, can_delete=None, created_at=None, created_epoch_millis=None, creator_id=None, creator_type=None, dimensions=None, end_time=None, hosts=None, id=None, is_ephemeral=None, is_user_event=None, metrics_used=None, name=None, running_state=None, start_time=None, summarized_events=None, table=None, tags=None, updated_at=None, updated_epoch_millis=None, updater_id=None, _configuration=None):  # noqa: E501
        """Event - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._alert_tags = None
        self._annotations = None
        self._can_close = None
        self._can_delete = None
        self._created_at = None
        self._created_epoch_millis = None
        self._creator_id = None
        self._creator_type = None
        self._dimensions = None
        self._end_time = None
        self._hosts = None
        self._id = None
        self._is_ephemeral = None
        self._is_user_event = None
        self._metrics_used = None
        self._name = None
        self._running_state = None
        self._start_time = None
        self._summarized_events = None
        self._table = None
        self._tags = None
        self._updated_at = None
        self._updated_epoch_millis = None
        self._updater_id = None
        self.discriminator = None

        if alert_tags is not None:
            self.alert_tags = alert_tags
        self.annotations = annotations
        if can_close is not None:
            self.can_close = can_close
        if can_delete is not None:
            self.can_delete = can_delete
        if created_at is not None:
            self.created_at = created_at
        if created_epoch_millis is not None:
            self.created_epoch_millis = created_epoch_millis
        if creator_id is not None:
            self.creator_id = creator_id
        if creator_type is not None:
            self.creator_type = creator_type
        if dimensions is not None:
            self.dimensions = dimensions
        if end_time is not None:
            self.end_time = end_time
        if hosts is not None:
            self.hosts = hosts
        if id is not None:
            self.id = id
        if is_ephemeral is not None:
            self.is_ephemeral = is_ephemeral
        if is_user_event is not None:
            self.is_user_event = is_user_event
        if metrics_used is not None:
            self.metrics_used = metrics_used
        self.name = name
        if running_state is not None:
            self.running_state = running_state
        self.start_time = start_time
        if summarized_events is not None:
            self.summarized_events = summarized_events
        if table is not None:
            self.table = table
        if tags is not None:
            self.tags = tags
        if updated_at is not None:
            self.updated_at = updated_at
        if updated_epoch_millis is not None:
            self.updated_epoch_millis = updated_epoch_millis
        if updater_id is not None:
            self.updater_id = updater_id

    @property
    def alert_tags(self):
        """Gets the alert_tags of this Event.  # noqa: E501

        The list of tags on the alert which created this event.  # noqa: E501

        :return: The alert_tags of this Event.  # noqa: E501
        :rtype: list[str]
        """
        return self._alert_tags

    @alert_tags.setter
    def alert_tags(self, alert_tags):
        """Sets the alert_tags of this Event.

        The list of tags on the alert which created this event.  # noqa: E501

        :param alert_tags: The alert_tags of this Event.  # noqa: E501
        :type: list[str]
        """

        self._alert_tags = alert_tags

    @property
    def annotations(self):
        """Gets the annotations of this Event.  # noqa: E501

        A string->string map of additional annotations on the event  # noqa: E501

        :return: The annotations of this Event.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._annotations

    @annotations.setter
    def annotations(self, annotations):
        """Sets the annotations of this Event.

        A string->string map of additional annotations on the event  # noqa: E501

        :param annotations: The annotations of this Event.  # noqa: E501
        :type: dict(str, str)
        """
        if self._configuration.client_side_validation and annotations is None:
            raise ValueError("Invalid value for `annotations`, must not be `None`")  # noqa: E501

        self._annotations = annotations

    @property
    def can_close(self):
        """Gets the can_close of this Event.  # noqa: E501


        :return: The can_close of this Event.  # noqa: E501
        :rtype: bool
        """
        return self._can_close

    @can_close.setter
    def can_close(self, can_close):
        """Sets the can_close of this Event.


        :param can_close: The can_close of this Event.  # noqa: E501
        :type: bool
        """

        self._can_close = can_close

    @property
    def can_delete(self):
        """Gets the can_delete of this Event.  # noqa: E501


        :return: The can_delete of this Event.  # noqa: E501
        :rtype: bool
        """
        return self._can_delete

    @can_delete.setter
    def can_delete(self, can_delete):
        """Sets the can_delete of this Event.


        :param can_delete: The can_delete of this Event.  # noqa: E501
        :type: bool
        """

        self._can_delete = can_delete

    @property
    def created_at(self):
        """Gets the created_at of this Event.  # noqa: E501


        :return: The created_at of this Event.  # noqa: E501
        :rtype: int
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Event.


        :param created_at: The created_at of this Event.  # noqa: E501
        :type: int
        """

        self._created_at = created_at

    @property
    def created_epoch_millis(self):
        """Gets the created_epoch_millis of this Event.  # noqa: E501


        :return: The created_epoch_millis of this Event.  # noqa: E501
        :rtype: int
        """
        return self._created_epoch_millis

    @created_epoch_millis.setter
    def created_epoch_millis(self, created_epoch_millis):
        """Sets the created_epoch_millis of this Event.


        :param created_epoch_millis: The created_epoch_millis of this Event.  # noqa: E501
        :type: int
        """

        self._created_epoch_millis = created_epoch_millis

    @property
    def creator_id(self):
        """Gets the creator_id of this Event.  # noqa: E501


        :return: The creator_id of this Event.  # noqa: E501
        :rtype: str
        """
        return self._creator_id

    @creator_id.setter
    def creator_id(self, creator_id):
        """Sets the creator_id of this Event.


        :param creator_id: The creator_id of this Event.  # noqa: E501
        :type: str
        """

        self._creator_id = creator_id

    @property
    def creator_type(self):
        """Gets the creator_type of this Event.  # noqa: E501


        :return: The creator_type of this Event.  # noqa: E501
        :rtype: list[str]
        """
        return self._creator_type

    @creator_type.setter
    def creator_type(self, creator_type):
        """Sets the creator_type of this Event.


        :param creator_type: The creator_type of this Event.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["USER", "ALERT", "SYSTEM"]  # noqa: E501
        if (self._configuration.client_side_validation and
                not set(creator_type).issubset(set(allowed_values))):  # noqa: E501
            raise ValueError(
                "Invalid values for `creator_type` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(creator_type) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._creator_type = creator_type

    @property
    def dimensions(self):
        """Gets the dimensions of this Event.  # noqa: E501

        A string-><list of strings> map of additional dimension info on the event  # noqa: E501

        :return: The dimensions of this Event.  # noqa: E501
        :rtype: dict(str, list[str])
        """
        return self._dimensions

    @dimensions.setter
    def dimensions(self, dimensions):
        """Sets the dimensions of this Event.

        A string-><list of strings> map of additional dimension info on the event  # noqa: E501

        :param dimensions: The dimensions of this Event.  # noqa: E501
        :type: dict(str, list[str])
        """

        self._dimensions = dimensions

    @property
    def end_time(self):
        """Gets the end_time of this Event.  # noqa: E501

        End time of the event, in epoch millis.  Set to startTime + 1 for an instantaneous event  # noqa: E501

        :return: The end_time of this Event.  # noqa: E501
        :rtype: int
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this Event.

        End time of the event, in epoch millis.  Set to startTime + 1 for an instantaneous event  # noqa: E501

        :param end_time: The end_time of this Event.  # noqa: E501
        :type: int
        """

        self._end_time = end_time

    @property
    def hosts(self):
        """Gets the hosts of this Event.  # noqa: E501

        A list of sources/hosts affected by the event  # noqa: E501

        :return: The hosts of this Event.  # noqa: E501
        :rtype: list[str]
        """
        return self._hosts

    @hosts.setter
    def hosts(self, hosts):
        """Sets the hosts of this Event.

        A list of sources/hosts affected by the event  # noqa: E501

        :param hosts: The hosts of this Event.  # noqa: E501
        :type: list[str]
        """

        self._hosts = hosts

    @property
    def id(self):
        """Gets the id of this Event.  # noqa: E501


        :return: The id of this Event.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Event.


        :param id: The id of this Event.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def is_ephemeral(self):
        """Gets the is_ephemeral of this Event.  # noqa: E501

        Whether the event is an artificial event generated by a literal expression or alert backtesting, i.e. not stored in the Wavefront backend  # noqa: E501

        :return: The is_ephemeral of this Event.  # noqa: E501
        :rtype: bool
        """
        return self._is_ephemeral

    @is_ephemeral.setter
    def is_ephemeral(self, is_ephemeral):
        """Sets the is_ephemeral of this Event.

        Whether the event is an artificial event generated by a literal expression or alert backtesting, i.e. not stored in the Wavefront backend  # noqa: E501

        :param is_ephemeral: The is_ephemeral of this Event.  # noqa: E501
        :type: bool
        """

        self._is_ephemeral = is_ephemeral

    @property
    def is_user_event(self):
        """Gets the is_user_event of this Event.  # noqa: E501

        Whether this event was created by a user, versus the system.  Default: system  # noqa: E501

        :return: The is_user_event of this Event.  # noqa: E501
        :rtype: bool
        """
        return self._is_user_event

    @is_user_event.setter
    def is_user_event(self, is_user_event):
        """Sets the is_user_event of this Event.

        Whether this event was created by a user, versus the system.  Default: system  # noqa: E501

        :param is_user_event: The is_user_event of this Event.  # noqa: E501
        :type: bool
        """

        self._is_user_event = is_user_event

    @property
    def metrics_used(self):
        """Gets the metrics_used of this Event.  # noqa: E501

        A list of metrics affected by the event  # noqa: E501

        :return: The metrics_used of this Event.  # noqa: E501
        :rtype: list[str]
        """
        return self._metrics_used

    @metrics_used.setter
    def metrics_used(self, metrics_used):
        """Sets the metrics_used of this Event.

        A list of metrics affected by the event  # noqa: E501

        :param metrics_used: The metrics_used of this Event.  # noqa: E501
        :type: list[str]
        """

        self._metrics_used = metrics_used

    @property
    def name(self):
        """Gets the name of this Event.  # noqa: E501

        The name of the event.  If 'annotations.prettyName' is present, 'name' will be equivalent to that value  # noqa: E501

        :return: The name of this Event.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Event.

        The name of the event.  If 'annotations.prettyName' is present, 'name' will be equivalent to that value  # noqa: E501

        :param name: The name of this Event.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def running_state(self):
        """Gets the running_state of this Event.  # noqa: E501


        :return: The running_state of this Event.  # noqa: E501
        :rtype: str
        """
        return self._running_state

    @running_state.setter
    def running_state(self, running_state):
        """Sets the running_state of this Event.


        :param running_state: The running_state of this Event.  # noqa: E501
        :type: str
        """
        allowed_values = ["ONGOING", "PENDING", "ENDED"]  # noqa: E501
        if (self._configuration.client_side_validation and
                running_state not in allowed_values):
            raise ValueError(
                "Invalid value for `running_state` ({0}), must be one of {1}"  # noqa: E501
                .format(running_state, allowed_values)
            )

        self._running_state = running_state

    @property
    def start_time(self):
        """Gets the start_time of this Event.  # noqa: E501

        Start time of the event, in epoch millis.  If the JSON value is missing or set to 0, startTime will be set to the current time  # noqa: E501

        :return: The start_time of this Event.  # noqa: E501
        :rtype: int
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this Event.

        Start time of the event, in epoch millis.  If the JSON value is missing or set to 0, startTime will be set to the current time  # noqa: E501

        :param start_time: The start_time of this Event.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and start_time is None:
            raise ValueError("Invalid value for `start_time`, must not be `None`")  # noqa: E501

        self._start_time = start_time

    @property
    def summarized_events(self):
        """Gets the summarized_events of this Event.  # noqa: E501

        In some event queries, multiple events that occur nearly simultaneously are summarized under a single event.  This value specifies the number of events summarized under this one  # noqa: E501

        :return: The summarized_events of this Event.  # noqa: E501
        :rtype: int
        """
        return self._summarized_events

    @summarized_events.setter
    def summarized_events(self, summarized_events):
        """Sets the summarized_events of this Event.

        In some event queries, multiple events that occur nearly simultaneously are summarized under a single event.  This value specifies the number of events summarized under this one  # noqa: E501

        :param summarized_events: The summarized_events of this Event.  # noqa: E501
        :type: int
        """

        self._summarized_events = summarized_events

    @property
    def table(self):
        """Gets the table of this Event.  # noqa: E501

        The customer to which the event belongs  # noqa: E501

        :return: The table of this Event.  # noqa: E501
        :rtype: str
        """
        return self._table

    @table.setter
    def table(self, table):
        """Sets the table of this Event.

        The customer to which the event belongs  # noqa: E501

        :param table: The table of this Event.  # noqa: E501
        :type: str
        """

        self._table = table

    @property
    def tags(self):
        """Gets the tags of this Event.  # noqa: E501

        A list of event tags  # noqa: E501

        :return: The tags of this Event.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this Event.

        A list of event tags  # noqa: E501

        :param tags: The tags of this Event.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def updated_at(self):
        """Gets the updated_at of this Event.  # noqa: E501


        :return: The updated_at of this Event.  # noqa: E501
        :rtype: int
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this Event.


        :param updated_at: The updated_at of this Event.  # noqa: E501
        :type: int
        """

        self._updated_at = updated_at

    @property
    def updated_epoch_millis(self):
        """Gets the updated_epoch_millis of this Event.  # noqa: E501


        :return: The updated_epoch_millis of this Event.  # noqa: E501
        :rtype: int
        """
        return self._updated_epoch_millis

    @updated_epoch_millis.setter
    def updated_epoch_millis(self, updated_epoch_millis):
        """Sets the updated_epoch_millis of this Event.


        :param updated_epoch_millis: The updated_epoch_millis of this Event.  # noqa: E501
        :type: int
        """

        self._updated_epoch_millis = updated_epoch_millis

    @property
    def updater_id(self):
        """Gets the updater_id of this Event.  # noqa: E501


        :return: The updater_id of this Event.  # noqa: E501
        :rtype: str
        """
        return self._updater_id

    @updater_id.setter
    def updater_id(self, updater_id):
        """Sets the updater_id of this Event.


        :param updater_id: The updater_id of this Event.  # noqa: E501
        :type: str
        """

        self._updater_id = updater_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Event, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Event):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Event):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class ExternalLink(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_epoch_millis': 'int',
        'creator_id': 'str',
        'description': 'str',
        'id': 'str',
        'is_log_integration': 'bool',
        'metric_filter_regex': 'str',
        'name': 'str',
        'point_tag_filter_regexes': 'dict(str, str)',
        'source_filter_regex': 'str',
        'template': 'str',
        'updated_epoch_millis': 'int',
        'updater_id': 'str'
    }

    attribute_map = {
        'created_epoch_millis': 'createdEpochMillis',
        'creator_id': 'creatorId',
        'description': 'description',
        'id': 'id',
        'is_log_integration': 'isLogIntegration',
        'metric_filter_regex': 'metricFilterRegex',
        'name': 'name',
        'point_tag_filter_regexes': 'pointTagFilterRegexes',
        'source_filter_regex': 'sourceFilterRegex',
        'template': 'template',
        'updated_epoch_millis': 'updatedEpochMillis',
        'updater_id': 'updaterId'
    }

    def __init__(self, created_epoch_millis=None, creator_id=None, description=None, id=None, is_log_integration=None, metric_filter_regex=None, name=None, point_tag_filter_regexes=None, source_filter_regex=None, template=None, updated_epoch_millis=None, updater_id=None, _configuration=None):  # noqa: E501
        """ExternalLink - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._created_epoch_millis = None
        self._creator_id = None
        self._description = None
        self._id = None
        self._is_log_integration = None
        self._metric_filter_regex = None
        self._name = None
        self._point_tag_filter_regexes = None
        self._source_filter_regex = None
        self._template = None
        self._updated_epoch_millis = None
        self._updater_id = None
        self.discriminator = None

        if created_epoch_millis is not None:
            self.created_epoch_millis = created_epoch_millis
        if creator_id is not None:
            self.creator_id = creator_id
        self.description = description
        if id is not None:
            self.id = id
        if is_log_integration is not None:
            self.is_log_integration = is_log_integration
        if metric_filter_regex is not None:
            self.metric_filter_regex = metric_filter_regex
        self.name = name
        if point_tag_filter_regexes is not None:
            self.point_tag_filter_regexes = point_tag_filter_regexes
        if source_filter_regex is not None:
            self.source_filter_regex = source_filter_regex
        self.template = template
        if updated_epoch_millis is not None:
            self.updated_epoch_millis = updated_epoch_millis
        if updater_id is not None:
            self.updater_id = updater_id

    @property
    def created_epoch_millis(self):
        """Gets the created_epoch_millis of this ExternalLink.  # noqa: E501


        :return: The created_epoch_millis of this ExternalLink.  # noqa: E501
        :rtype: int
        """
        return self._created_epoch_millis

    @created_epoch_millis.setter
    def created_epoch_millis(self, created_epoch_millis):
        """Sets the created_epoch_millis of this ExternalLink.


        :param created_epoch_millis: The created_epoch_millis of this ExternalLink.  # noqa: E501
        :type: int
        """

        self._created_epoch_millis = created_epoch_millis

    @property
    def creator_id(self):
        """Gets the creator_id of this ExternalLink.  # noqa: E501


        :return: The creator_id of this ExternalLink.  # noqa: E501
        :rtype: str
        """
        return self._creator_id

    @creator_id.setter
    def creator_id(self, creator_id):
        """Sets the creator_id of this ExternalLink.


        :param creator_id: The creator_id of this ExternalLink.  # noqa: E501
        :type: str
        """

        self._creator_id = creator_id

    @property
    def description(self):
        """Gets the description of this ExternalLink.  # noqa: E501

        Human-readable description for this external link  # noqa: E501

        :return: The description of this ExternalLink.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ExternalLink.

        Human-readable description for this external link  # noqa: E501

        :param description: The description of this ExternalLink.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and description is None:
            raise ValueError("Invalid value for `description`, must not be `None`")  # noqa: E501

        self._description = description

    @property
    def id(self):
        """Gets the id of this ExternalLink.  # noqa: E501


        :return: The id of this ExternalLink.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ExternalLink.


        :param id: The id of this ExternalLink.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def is_log_integration(self):
        """Gets the is_log_integration of this ExternalLink.  # noqa: E501

        Whether this is a \"Log Integration\" subType of external link  # noqa: E501

        :return: The is_log_integration of this ExternalLink.  # noqa: E501
        :rtype: bool
        """
        return self._is_log_integration

    @is_log_integration.setter
    def is_log_integration(self, is_log_integration):
        """Sets the is_log_integration of this ExternalLink.

        Whether this is a \"Log Integration\" subType of external link  # noqa: E501

        :param is_log_integration: The is_log_integration of this ExternalLink.  # noqa: E501
        :type: bool
        """

        self._is_log_integration = is_log_integration

    @property
    def metric_filter_regex(self):
        """Gets the metric_filter_regex of this ExternalLink.  # noqa: E501

        Controls whether a link displayed in the context menu of a highlighted series.  If present, the metric name of the highlighted series must match this regular expression in order for the link to be displayed  # noqa: E501

        :return: The metric_filter_regex of this ExternalLink.  # noqa: E501
        :rtype: str
        """
        return self._metric_filter_regex

    @metric_filter_regex.setter
    def metric_filter_regex(self, metric_filter_regex):
        """Sets the metric_filter_regex of this ExternalLink.

        Controls whether a link displayed in the context menu of a highlighted series.  If present, the metric name of the highlighted series must match this regular expression in order for the link to be displayed  # noqa: E501

        :param metric_filter_regex: The metric_filter_regex of this ExternalLink.  # noqa: E501
        :type: str
        """

        self._metric_filter_regex = metric_filter_regex

    @property
    def name(self):
        """Gets the name of this ExternalLink.  # noqa: E501

        Name of the external link.  Will be displayed in context (right-click) menus on charts  # noqa: E501

        :return: The name of this ExternalLink.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ExternalLink.

        Name of the external link.  Will be displayed in context (right-click) menus on charts  # noqa: E501

        :param name: The name of this ExternalLink.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def point_tag_filter_regexes(self):
        """Gets the point_tag_filter_regexes of this ExternalLink.  # noqa: E501

        Controls whether a link displayed in the context menu of a highlighted series.  This is a map from string to regular expression. The highlighted series must contain point tags whose keys are present in the keys of this map and whose values match the regular expressions associated with those keys in order for the link to be displayed  # noqa: E501

        :return: The point_tag_filter_regexes of this ExternalLink.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._point_tag_filter_regexes

    @point_tag_filter_regexes.setter
    def point_tag_filter_regexes(self, point_tag_filter_regexes):
        """Sets the point_tag_filter_regexes of this ExternalLink.

        Controls whether a link displayed in the context menu of a highlighted series.  This is a map from string to regular expression. The highlighted series must contain point tags whose keys are present in the keys of this map and whose values match the regular expressions associated with those keys in order for the link to be displayed  # noqa: E501

        :param point_tag_filter_regexes: The point_tag_filter_regexes of this ExternalLink.  # noqa: E501
        :type: dict(str, str)
        """

        self._point_tag_filter_regexes = point_tag_filter_regexes

    @property
    def source_filter_regex(self):
        """Gets the source_filter_regex of this ExternalLink.  # noqa: E501

        Controls whether a link displayed in the context menu of a highlighted series.  If present, the source name of the highlighted series must match this regular expression in order for the link to be displayed  # noqa: E501

        :return: The source_filter_regex of this ExternalLink.  # noqa: E501
        :rtype: str
        """
        return self._source_filter_regex

    @source_filter_regex.setter
    def source_filter_regex(self, source_filter_regex):
        """Sets the source_filter_regex of this ExternalLink.

        Controls whether a link displayed in the context menu of a highlighted series.  If present, the source name of the highlighted series must match this regular expression in order for the link to be displayed  # noqa: E501

        :param source_filter_regex: The source_filter_regex of this ExternalLink.  # noqa: E501
        :type: str
        """

        self._source_filter_regex = source_filter_regex

    @property
    def template(self):
        """Gets the template of this ExternalLink.  # noqa: E501

        The mustache template for this link.  This template must expand to a full URL, including scheme, origin, etc  # noqa: E501

        :return: The template of this ExternalLink.  # noqa: E501
        :rtype: str
        """
        return self._template

    @template.setter
    def template(self, template):
        """Sets the template of this ExternalLink.

        The mustache template for this link.  This template must expand to a full URL, including scheme, origin, etc  # noqa: E501

        :param template: The template of this ExternalLink.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and template is None:
            raise ValueError("Invalid value for `template`, must not be `None`")  # noqa: E501

        self._template = template

    @property
    def updated_epoch_millis(self):
        """Gets the updated_epoch_millis of this ExternalLink.  # noqa: E501


        :return: The updated_epoch_millis of this ExternalLink.  # noqa: E501
        :rtype: int
        """
        return self._updated_epoch_millis

    @updated_epoch_millis.setter
    def updated_epoch_millis(self, updated_epoch_millis):
        """Sets the updated_epoch_millis of this ExternalLink.


        :param updated_epoch_millis: The updated_epoch_millis of this ExternalLink.  # noqa: E501
        :type: int
        """

        self._updated_epoch_millis = updated_epoch_millis

    @property
    def updater_id(self):
        """Gets the updater_id of this ExternalLink.  # noqa: E501


        :return: The updater_id of this ExternalLink.  # noqa: E501
        :rtype: str
        """
        return self._updater_id

    @updater_id.setter
    def updater_id(self, updater_id):
        """Sets the updater_id of this ExternalLink.


        :param updater_id: The updater_id of this ExternalLink.  # noqa: E501
        :type: str
        """

        self._updater_id = updater_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ExternalLink, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExternalLink):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ExternalLink):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from wavefront_api_client.api_client import ApiClient


class MetricApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_metric_details(self, m, **kwargs):  # noqa: E501
        """Get more details on a metric, including reporting sources and approximate last time reported  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_metric_details(m, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str m: Metric name (required)
        :param int l: limit
        :param str c: cursor value to continue if the number of results exceeds 1000
        :param list[str] h: glob pattern for sources to include in the query result
        :return: MetricDetailsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_metric_details_with_http_info(m, **kwargs)  # noqa: E501
        else:
            (data) = self.get_metric_details_with_http_info(m, **kwargs)  # noqa: E501
            return data

    def get_metric_details_with_http_info(self, m, **kwargs):  # noqa: E501
        """Get more details on a metric, including reporting sources and approximate last time reported  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_metric_details_with_http_info(m, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str m: Metric name (required)
        :param int l: limit
        :param str c: cursor value to continue if the number of results exceeds 1000
        :param list[str] h: glob pattern for sources to include in the query result
        :return: MetricDetailsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['m', 'l', 'c', 'h']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_metric_details" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'm' is set
        if self.api_client.client_side_validation and ('m' not in params or
                                                       params['m'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `m` when calling `get_metric_details`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'm' in params:
            query_params.append(('m', params['m']))  # noqa: E501
        if 'l' in params:
            query_params.append(('l', params['l']))  # noqa: E501
        if 'c' in params:
            query_params.append(('c', params['c']))  # noqa: E501
        if 'h' in params:
            query_params.append(('h', params['h']))  # noqa: E501
            collection_formats['h'] = 'multi'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/x-javascript', 'application/javascript'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/chart/metric/detail', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MetricDetailsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class UserGroupWrite(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_epoch_millis': 'int',
        'customer': 'str',
        'description': 'str',
        'id': 'str',
        'name': 'str',
        'permissions': 'list[str]',
        'role_i_ds': 'list[str]'
    }

    attribute_map = {
        'created_epoch_millis': 'createdEpochMillis',
        'customer': 'customer',
        'description': 'description',
        'id': 'id',
        'name': 'name',
        'permissions': 'permissions',
        'role_i_ds': 'roleIDs'
    }

    def __init__(self, created_epoch_millis=None, customer=None, description=None, id=None, name=None, permissions=None, role_i_ds=None, _configuration=None):  # noqa: E501
        """UserGroupWrite - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._created_epoch_millis = None
        self._customer = None
        self._description = None
        self._id = None
        self._name = None
        self._permissions = None
        self._role_i_ds = None
        self.discriminator = None

        if created_epoch_millis is not None:
            self.created_epoch_millis = created_epoch_millis
        if customer is not None:
            self.customer = customer
        if description is not None:
            self.description = description
        if id is not None:
            self.id = id
        self.name = name
        self.permissions = permissions
        self.role_i_ds = role_i_ds

    @property
    def created_epoch_millis(self):
        """Gets the created_epoch_millis of this UserGroupWrite.  # noqa: E501


        :return: The created_epoch_millis of this UserGroupWrite.  # noqa: E501
        :rtype: int
        """
        return self._created_epoch_millis

    @created_epoch_millis.setter
    def created_epoch_millis(self, created_epoch_millis):
        """Sets the created_epoch_millis of this UserGroupWrite.


        :param created_epoch_millis: The created_epoch_millis of this UserGroupWrite.  # noqa: E501
        :type: int
        """

        self._created_epoch_millis = created_epoch_millis

    @property
    def customer(self):
        """Gets the customer of this UserGroupWrite.  # noqa: E501

        The id of the customer to which the user group belongs  # noqa: E501

        :return: The customer of this UserGroupWrite.  # noqa: E501
        :rtype: str
        """
        return self._customer

    @customer.setter
    def customer(self, customer):
        """Sets the customer of this UserGroupWrite.

        The id of the customer to which the user group belongs  # noqa: E501

        :param customer: The customer of this UserGroupWrite.  # noqa: E501
        :type: str
        """

        self._customer = customer

    @property
    def description(self):
        """Gets the description of this UserGroupWrite.  # noqa: E501

        The description of the user group  # noqa: E501

        :return: The description of this UserGroupWrite.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this UserGroupWrite.

        The description of the user group  # noqa: E501

        :param description: The description of this UserGroupWrite.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def id(self):
        """Gets the id of this UserGroupWrite.  # noqa: E501

        The unique identifier of the user group  # noqa: E501

        :return: The id of this UserGroupWrite.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this UserGroupWrite.

        The unique identifier of the user group  # noqa: E501

        :param id: The id of this UserGroupWrite.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this UserGroupWrite.  # noqa: E501

        The name of the user group  # noqa: E501

        :return: The name of this UserGroupWrite.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UserGroupWrite.

        The name of the user group  # noqa: E501

        :param name: The name of this UserGroupWrite.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def permissions(self):
        """Gets the permissions of this UserGroupWrite.  # noqa: E501

        List of permissions the user group has been granted access to. Become obsolete. Use Roles parameter to setup group permission.  # noqa: E501

        :return: The permissions of this UserGroupWrite.  # noqa: E501
        :rtype: list[str]
        """
        return self._permissions

    @permissions.setter
    def permissions(self, permissions):
        """Sets the permissions of this UserGroupWrite.

        List of permissions the user group has been granted access to. Become obsolete. Use Roles parameter to setup group permission.  # noqa: E501

        :param permissions: The permissions of this UserGroupWrite.  # noqa: E501
        :type: list[str]
        """
        if self._configuration.client_side_validation and permissions is None:
            raise ValueError("Invalid value for `permissions`, must not be `None`")  # noqa: E501

        self._permissions = permissions

    @property
    def role_i_ds(self):
        """Gets the role_i_ds of this UserGroupWrite.  # noqa: E501

        List of role IDs the user group has been linked to.  # noqa: E501

        :return: The role_i_ds of this UserGroupWrite.  # noqa: E501
        :rtype: list[str]
        """
        return self._role_i_ds

    @role_i_ds.setter
    def role_i_ds(self, role_i_ds):
        """Sets the role_i_ds of this UserGroupWrite.

        List of role IDs the user group has been linked to.  # noqa: E501

        :param role_i_ds: The role_i_ds of this UserGroupWrite.  # noqa: E501
        :type: list[str]
        """
        if self._configuration.client_side_validation and role_i_ds is None:
            raise ValueError("Invalid value for `role_i_ds`, must not be `None`")  # noqa: E501

        self._role_i_ds = role_i_ds

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UserGroupWrite, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserGroupWrite):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserGroupWrite):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class MetricStatus(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ever': 'bool',
        'now': 'bool',
        'recent_except_now': 'bool',
        'status': 'str'
    }

    attribute_map = {
        'ever': 'ever',
        'now': 'now',
        'recent_except_now': 'recentExceptNow',
        'status': 'status'
    }

    def __init__(self, ever=None, now=None, recent_except_now=None, status=None, _configuration=None):  # noqa: E501
        """MetricStatus - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._ever = None
        self._now = None
        self._recent_except_now = None
        self._status = None
        self.discriminator = None

        if ever is not None:
            self.ever = ever
        if now is not None:
            self.now = now
        if recent_except_now is not None:
            self.recent_except_now = recent_except_now
        if status is not None:
            self.status = status

    @property
    def ever(self):
        """Gets the ever of this MetricStatus.  # noqa: E501


        :return: The ever of this MetricStatus.  # noqa: E501
        :rtype: bool
        """
        return self._ever

    @ever.setter
    def ever(self, ever):
        """Sets the ever of this MetricStatus.


        :param ever: The ever of this MetricStatus.  # noqa: E501
        :type: bool
        """

        self._ever = ever

    @property
    def now(self):
        """Gets the now of this MetricStatus.  # noqa: E501


        :return: The now of this MetricStatus.  # noqa: E501
        :rtype: bool
        """
        return self._now

    @now.setter
    def now(self, now):
        """Sets the now of this MetricStatus.


        :param now: The now of this MetricStatus.  # noqa: E501
        :type: bool
        """

        self._now = now

    @property
    def recent_except_now(self):
        """Gets the recent_except_now of this MetricStatus.  # noqa: E501


        :return: The recent_except_now of this MetricStatus.  # noqa: E501
        :rtype: bool
        """
        return self._recent_except_now

    @recent_except_now.setter
    def recent_except_now(self, recent_except_now):
        """Sets the recent_except_now of this MetricStatus.


        :param recent_except_now: The recent_except_now of this MetricStatus.  # noqa: E501
        :type: bool
        """

        self._recent_except_now = recent_except_now

    @property
    def status(self):
        """Gets the status of this MetricStatus.  # noqa: E501


        :return: The status of this MetricStatus.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this MetricStatus.


        :param status: The status of this MetricStatus.  # noqa: E501
        :type: str
        """
        allowed_values = ["OK", "PENDING"]  # noqa: E501
        if (self._configuration.client_side_validation and
                status not in allowed_values):
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MetricStatus, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MetricStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MetricStatus):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import wavefront_api_client
from wavefront_api_client.api.notificant_api import NotificantApi  # noqa: E501
from wavefront_api_client.rest import ApiException


class TestNotificantApi(unittest.TestCase):
    """NotificantApi unit test stubs"""

    def setUp(self):
        self.api = wavefront_api_client.api.notificant_api.NotificantApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_notificant(self):
        """Test case for create_notificant

        Create a notification target  # noqa: E501
        """
        pass

    def test_delete_notificant(self):
        """Test case for delete_notificant

        Delete a specific notification target  # noqa: E501
        """
        pass

    def test_get_all_notificants(self):
        """Test case for get_all_notificants

        Get all notification targets for a customer  # noqa: E501
        """
        pass

    def test_get_notificant(self):
        """Test case for get_notificant

        Get a specific notification target  # noqa: E501
        """
        pass

    def test_test_notificant(self):
        """Test case for test_notificant

        Test a specific notification target  # noqa: E501
        """
        pass

    def test_update_notificant(self):
        """Test case for update_notificant

        Update a specific notification target  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class Chart(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'anomaly_sample_size': 'str',
        'anomaly_severity': 'str',
        'anomaly_type': 'str',
        'base': 'int',
        'chart_attributes': 'JsonNode',
        'chart_settings': 'ChartSettings',
        'description': 'str',
        'display_confidence_bounds': 'bool',
        'filter_out_non_anomalies': 'bool',
        'include_obsolete_metrics': 'bool',
        'interpolate_points': 'bool',
        'name': 'str',
        'no_default_events': 'bool',
        'sources': 'list[ChartSourceQuery]',
        'summarization': 'str',
        'units': 'str'
    }

    attribute_map = {
        'anomaly_sample_size': 'anomalySampleSize',
        'anomaly_severity': 'anomalySeverity',
        'anomaly_type': 'anomalyType',
        'base': 'base',
        'chart_attributes': 'chartAttributes',
        'chart_settings': 'chartSettings',
        'description': 'description',
        'display_confidence_bounds': 'displayConfidenceBounds',
        'filter_out_non_anomalies': 'filterOutNonAnomalies',
        'include_obsolete_metrics': 'includeObsoleteMetrics',
        'interpolate_points': 'interpolatePoints',
        'name': 'name',
        'no_default_events': 'noDefaultEvents',
        'sources': 'sources',
        'summarization': 'summarization',
        'units': 'units'
    }

    def __init__(self, anomaly_sample_size=None, anomaly_severity=None, anomaly_type=None, base=None, chart_attributes=None, chart_settings=None, description=None, display_confidence_bounds=None, filter_out_non_anomalies=None, include_obsolete_metrics=None, interpolate_points=None, name=None, no_default_events=None, sources=None, summarization=None, units=None, _configuration=None):  # noqa: E501
        """Chart - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._anomaly_sample_size = None
        self._anomaly_severity = None
        self._anomaly_type = None
        self._base = None
        self._chart_attributes = None
        self._chart_settings = None
        self._description = None
        self._display_confidence_bounds = None
        self._filter_out_non_anomalies = None
        self._include_obsolete_metrics = None
        self._interpolate_points = None
        self._name = None
        self._no_default_events = None
        self._sources = None
        self._summarization = None
        self._units = None
        self.discriminator = None

        if anomaly_sample_size is not None:
            self.anomaly_sample_size = anomaly_sample_size
        if anomaly_severity is not None:
            self.anomaly_severity = anomaly_severity
        if anomaly_type is not None:
            self.anomaly_type = anomaly_type
        if base is not None:
            self.base = base
        if chart_attributes is not None:
            self.chart_attributes = chart_attributes
        if chart_settings is not None:
            self.chart_settings = chart_settings
        if description is not None:
            self.description = description
        if display_confidence_bounds is not None:
            self.display_confidence_bounds = display_confidence_bounds
        if filter_out_non_anomalies is not None:
            self.filter_out_non_anomalies = filter_out_non_anomalies
        if include_obsolete_metrics is not None:
            self.include_obsolete_metrics = include_obsolete_metrics
        if interpolate_points is not None:
            self.interpolate_points = interpolate_points
        self.name = name
        if no_default_events is not None:
            self.no_default_events = no_default_events
        self.sources = sources
        if summarization is not None:
            self.summarization = summarization
        if units is not None:
            self.units = units

    @property
    def anomaly_sample_size(self):
        """Gets the anomaly_sample_size of this Chart.  # noqa: E501

        The amount of historical data to use for anomaly detection baselining  # noqa: E501

        :return: The anomaly_sample_size of this Chart.  # noqa: E501
        :rtype: str
        """
        return self._anomaly_sample_size

    @anomaly_sample_size.setter
    def anomaly_sample_size(self, anomaly_sample_size):
        """Sets the anomaly_sample_size of this Chart.

        The amount of historical data to use for anomaly detection baselining  # noqa: E501

        :param anomaly_sample_size: The anomaly_sample_size of this Chart.  # noqa: E501
        :type: str
        """
        allowed_values = ["2", "8", "35"]  # noqa: E501
        if (self._configuration.client_side_validation and
                anomaly_sample_size not in allowed_values):
            raise ValueError(
                "Invalid value for `anomaly_sample_size` ({0}), must be one of {1}"  # noqa: E501
                .format(anomaly_sample_size, allowed_values)
            )

        self._anomaly_sample_size = anomaly_sample_size

    @property
    def anomaly_severity(self):
        """Gets the anomaly_severity of this Chart.  # noqa: E501

        Anomaly Severity. Default medium  # noqa: E501

        :return: The anomaly_severity of this Chart.  # noqa: E501
        :rtype: str
        """
        return self._anomaly_severity

    @anomaly_severity.setter
    def anomaly_severity(self, anomaly_severity):
        """Sets the anomaly_severity of this Chart.

        Anomaly Severity. Default medium  # noqa: E501

        :param anomaly_severity: The anomaly_severity of this Chart.  # noqa: E501
        :type: str
        """
        allowed_values = ["low", "medium", "high"]  # noqa: E501
        if (self._configuration.client_side_validation and
                anomaly_severity not in allowed_values):
            raise ValueError(
                "Invalid value for `anomaly_severity` ({0}), must be one of {1}"  # noqa: E501
                .format(anomaly_severity, allowed_values)
            )

        self._anomaly_severity = anomaly_severity

    @property
    def anomaly_type(self):
        """Gets the anomaly_type of this Chart.  # noqa: E501

        Anomaly Type. Default both  # noqa: E501

        :return: The anomaly_type of this Chart.  # noqa: E501
        :rtype: str
        """
        return self._anomaly_type

    @anomaly_type.setter
    def anomaly_type(self, anomaly_type):
        """Sets the anomaly_type of this Chart.

        Anomaly Type. Default both  # noqa: E501

        :param anomaly_type: The anomaly_type of this Chart.  # noqa: E501
        :type: str
        """
        allowed_values = ["both", "low", "high"]  # noqa: E501
        if (self._configuration.client_side_validation and
                anomaly_type not in allowed_values):
            raise ValueError(
                "Invalid value for `anomaly_type` ({0}), must be one of {1}"  # noqa: E501
                .format(anomaly_type, allowed_values)
            )

        self._anomaly_type = anomaly_type

    @property
    def base(self):
        """Gets the base of this Chart.  # noqa: E501

        If the chart has a log-scale Y-axis, the base for the logarithms  # noqa: E501

        :return: The base of this Chart.  # noqa: E501
        :rtype: int
        """
        return self._base

    @base.setter
    def base(self, base):
        """Sets the base of this Chart.

        If the chart has a log-scale Y-axis, the base for the logarithms  # noqa: E501

        :param base: The base of this Chart.  # noqa: E501
        :type: int
        """

        self._base = base

    @property
    def chart_attributes(self):
        """Gets the chart_attributes of this Chart.  # noqa: E501

        Experimental field for chart attributes  # noqa: E501

        :return: The chart_attributes of this Chart.  # noqa: E501
        :rtype: JsonNode
        """
        return self._chart_attributes

    @chart_attributes.setter
    def chart_attributes(self, chart_attributes):
        """Sets the chart_attributes of this Chart.

        Experimental field for chart attributes  # noqa: E501

        :param chart_attributes: The chart_attributes of this Chart.  # noqa: E501
        :type: JsonNode
        """

        self._chart_attributes = chart_attributes

    @property
    def chart_settings(self):
        """Gets the chart_settings of this Chart.  # noqa: E501


        :return: The chart_settings of this Chart.  # noqa: E501
        :rtype: ChartSettings
        """
        return self._chart_settings

    @chart_settings.setter
    def chart_settings(self, chart_settings):
        """Sets the chart_settings of this Chart.


        :param chart_settings: The chart_settings of this Chart.  # noqa: E501
        :type: ChartSettings
        """

        self._chart_settings = chart_settings

    @property
    def description(self):
        """Gets the description of this Chart.  # noqa: E501

        Description of the chart  # noqa: E501

        :return: The description of this Chart.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Chart.

        Description of the chart  # noqa: E501

        :param description: The description of this Chart.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def display_confidence_bounds(self):
        """Gets the display_confidence_bounds of this Chart.  # noqa: E501

        Whether to show confidence bounds. Default false  # noqa: E501

        :return: The display_confidence_bounds of this Chart.  # noqa: E501
        :rtype: bool
        """
        return self._display_confidence_bounds

    @display_confidence_bounds.setter
    def display_confidence_bounds(self, display_confidence_bounds):
        """Sets the display_confidence_bounds of this Chart.

        Whether to show confidence bounds. Default false  # noqa: E501

        :param display_confidence_bounds: The display_confidence_bounds of this Chart.  # noqa: E501
        :type: bool
        """

        self._display_confidence_bounds = display_confidence_bounds

    @property
    def filter_out_non_anomalies(self):
        """Gets the filter_out_non_anomalies of this Chart.  # noqa: E501

        Whether to filter out non anomalies. Default false  # noqa: E501

        :return: The filter_out_non_anomalies of this Chart.  # noqa: E501
        :rtype: bool
        """
        return self._filter_out_non_anomalies

    @filter_out_non_anomalies.setter
    def filter_out_non_anomalies(self, filter_out_non_anomalies):
        """Sets the filter_out_non_anomalies of this Chart.

        Whether to filter out non anomalies. Default false  # noqa: E501

        :param filter_out_non_anomalies: The filter_out_non_anomalies of this Chart.  # noqa: E501
        :type: bool
        """

        self._filter_out_non_anomalies = filter_out_non_anomalies

    @property
    def include_obsolete_metrics(self):
        """Gets the include_obsolete_metrics of this Chart.  # noqa: E501

        Whether to show obsolete metrics.  Default: false  # noqa: E501

        :return: The include_obsolete_metrics of this Chart.  # noqa: E501
        :rtype: bool
        """
        return self._include_obsolete_metrics

    @include_obsolete_metrics.setter
    def include_obsolete_metrics(self, include_obsolete_metrics):
        """Sets the include_obsolete_metrics of this Chart.

        Whether to show obsolete metrics.  Default: false  # noqa: E501

        :param include_obsolete_metrics: The include_obsolete_metrics of this Chart.  # noqa: E501
        :type: bool
        """

        self._include_obsolete_metrics = include_obsolete_metrics

    @property
    def interpolate_points(self):
        """Gets the interpolate_points of this Chart.  # noqa: E501

        Whether to interpolate points in the charts produced. Default: true  # noqa: E501

        :return: The interpolate_points of this Chart.  # noqa: E501
        :rtype: bool
        """
        return self._interpolate_points

    @interpolate_points.setter
    def interpolate_points(self, interpolate_points):
        """Sets the interpolate_points of this Chart.

        Whether to interpolate points in the charts produced. Default: true  # noqa: E501

        :param interpolate_points: The interpolate_points of this Chart.  # noqa: E501
        :type: bool
        """

        self._interpolate_points = interpolate_points

    @property
    def name(self):
        """Gets the name of this Chart.  # noqa: E501

        Name of the source  # noqa: E501

        :return: The name of this Chart.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Chart.

        Name of the source  # noqa: E501

        :param name: The name of this Chart.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def no_default_events(self):
        """Gets the no_default_events of this Chart.  # noqa: E501

        Whether to hide events related to the sources in the charts produced. Default false (i.e. shows events)  # noqa: E501

        :return: The no_default_events of this Chart.  # noqa: E501
        :rtype: bool
        """
        return self._no_default_events

    @no_default_events.setter
    def no_default_events(self, no_default_events):
        """Sets the no_default_events of this Chart.

        Whether to hide events related to the sources in the charts produced. Default false (i.e. shows events)  # noqa: E501

        :param no_default_events: The no_default_events of this Chart.  # noqa: E501
        :type: bool
        """

        self._no_default_events = no_default_events

    @property
    def sources(self):
        """Gets the sources of this Chart.  # noqa: E501

        Query expression to plot on the chart  # noqa: E501

        :return: The sources of this Chart.  # noqa: E501
        :rtype: list[ChartSourceQuery]
        """
        return self._sources

    @sources.setter
    def sources(self, sources):
        """Sets the sources of this Chart.

        Query expression to plot on the chart  # noqa: E501

        :param sources: The sources of this Chart.  # noqa: E501
        :type: list[ChartSourceQuery]
        """
        if self._configuration.client_side_validation and sources is None:
            raise ValueError("Invalid value for `sources`, must not be `None`")  # noqa: E501

        self._sources = sources

    @property
    def summarization(self):
        """Gets the summarization of this Chart.  # noqa: E501

        Summarization strategy for the chart.  MEAN is default  # noqa: E501

        :return: The summarization of this Chart.  # noqa: E501
        :rtype: str
        """
        return self._summarization

    @summarization.setter
    def summarization(self, summarization):
        """Sets the summarization of this Chart.

        Summarization strategy for the chart.  MEAN is default  # noqa: E501

        :param summarization: The summarization of this Chart.  # noqa: E501
        :type: str
        """
        allowed_values = ["MEAN", "MEDIAN", "MIN", "MAX", "SUM", "COUNT", "LAST", "FIRST"]  # noqa: E501
        if (self._configuration.client_side_validation and
                summarization not in allowed_values):
            raise ValueError(
                "Invalid value for `summarization` ({0}), must be one of {1}"  # noqa: E501
                .format(summarization, allowed_values)
            )

        self._summarization = summarization

    @property
    def units(self):
        """Gets the units of this Chart.  # noqa: E501

        String to label the units of the chart on the Y-axis  # noqa: E501

        :return: The units of this Chart.  # noqa: E501
        :rtype: str
        """
        return self._units

    @units.setter
    def units(self, units):
        """Sets the units of this Chart.

        String to label the units of the chart on the Y-axis  # noqa: E501

        :param units: The units of this Chart.  # noqa: E501
        :type: str
        """

        self._units = units

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Chart, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Chart):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Chart):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from wavefront_api_client.api.access_policy_api import AccessPolicyApi
from wavefront_api_client.api.account__user_and_service_account_api import AccountUserAndServiceAccountApi
from wavefront_api_client.api.alert_api import AlertApi
from wavefront_api_client.api.api_token_api import ApiTokenApi
from wavefront_api_client.api.cloud_integration_api import CloudIntegrationApi
from wavefront_api_client.api.dashboard_api import DashboardApi
from wavefront_api_client.api.derived_metric_api import DerivedMetricApi
from wavefront_api_client.api.direct_ingestion_api import DirectIngestionApi
from wavefront_api_client.api.event_api import EventApi
from wavefront_api_client.api.external_link_api import ExternalLinkApi
from wavefront_api_client.api.ingestion_spy_api import IngestionSpyApi
from wavefront_api_client.api.integration_api import IntegrationApi
from wavefront_api_client.api.maintenance_window_api import MaintenanceWindowApi
from wavefront_api_client.api.message_api import MessageApi
from wavefront_api_client.api.metric_api import MetricApi
from wavefront_api_client.api.metrics_policy_api import MetricsPolicyApi
from wavefront_api_client.api.monitored_application_api import MonitoredApplicationApi
from wavefront_api_client.api.monitored_service_api import MonitoredServiceApi
from wavefront_api_client.api.notificant_api import NotificantApi
from wavefront_api_client.api.proxy_api import ProxyApi
from wavefront_api_client.api.query_api import QueryApi
from wavefront_api_client.api.role_api import RoleApi
from wavefront_api_client.api.saved_search_api import SavedSearchApi
from wavefront_api_client.api.search_api import SearchApi
from wavefront_api_client.api.source_api import SourceApi
from wavefront_api_client.api.usage_api import UsageApi
from wavefront_api_client.api.user_api import UserApi
from wavefront_api_client.api.user_group_api import UserGroupApi
from wavefront_api_client.api.webhook_api import WebhookApi

# import ApiClient
from wavefront_api_client.api_client import ApiClient
from wavefront_api_client.configuration import Configuration
# import models into sdk package
from wavefront_api_client.models.aws_base_credentials import AWSBaseCredentials
from wavefront_api_client.models.access_control_element import AccessControlElement
from wavefront_api_client.models.access_control_list_read_dto import AccessControlListReadDTO
from wavefront_api_client.models.access_control_list_simple import AccessControlListSimple
from wavefront_api_client.models.access_control_list_write_dto import AccessControlListWriteDTO
from wavefront_api_client.models.access_policy import AccessPolicy
from wavefront_api_client.models.access_policy_rule_dto import AccessPolicyRuleDTO
from wavefront_api_client.models.account import Account
from wavefront_api_client.models.alert import Alert
from wavefront_api_client.models.alert_min import AlertMin
from wavefront_api_client.models.alert_route import AlertRoute
from wavefront_api_client.models.annotation import Annotation
from wavefront_api_client.models.anomaly import Anomaly
from wavefront_api_client.models.app_dynamics_configuration import AppDynamicsConfiguration
from wavefront_api_client.models.azure_activity_log_configuration import AzureActivityLogConfiguration
from wavefront_api_client.models.azure_base_credentials import AzureBaseCredentials
from wavefront_api_client.models.azure_configuration import AzureConfiguration
from wavefront_api_client.models.chart import Chart
from wavefront_api_client.models.chart_settings import ChartSettings
from wavefront_api_client.models.chart_source_query import ChartSourceQuery
from wavefront_api_client.models.class_loader import ClassLoader
from wavefront_api_client.models.cloud_integration import CloudIntegration
from wavefront_api_client.models.cloud_trail_configuration import CloudTrailConfiguration
from wavefront_api_client.models.cloud_watch_configuration import CloudWatchConfiguration
from wavefront_api_client.models.conversion import Conversion
from wavefront_api_client.models.conversion_object import ConversionObject
from wavefront_api_client.models.customer_facing_user_object import CustomerFacingUserObject
from wavefront_api_client.models.dashboard import Dashboard
from wavefront_api_client.models.dashboard_min import DashboardMin
from wavefront_api_client.models.dashboard_parameter_value import DashboardParameterValue
from wavefront_api_client.models.dashboard_section import DashboardSection
from wavefront_api_client.models.dashboard_section_row import DashboardSectionRow
from wavefront_api_client.models.derived_metric_definition import DerivedMetricDefinition
from wavefront_api_client.models.ec2_configuration import EC2Configuration
from wavefront_api_client.models.event import Event
from wavefront_api_client.models.event_search_request import EventSearchRequest
from wavefront_api_client.models.event_time_range import EventTimeRange
from wavefront_api_client.models.external_link import ExternalLink
from wavefront_api_client.models.facet_response import FacetResponse
from wavefront_api_client.models.facet_search_request_container import FacetSearchRequestContainer
from wavefront_api_client.models.facets_response_container import FacetsResponseContainer
from wavefront_api_client.models.facets_search_request_container import FacetsSearchRequestContainer
from wavefront_api_client.models.fast_reader_builder import FastReaderBuilder
from wavefront_api_client.models.field import Field
from wavefront_api_client.models.gcp_billing_configuration import GCPBillingConfiguration
from wavefront_api_client.models.gcp_configuration import GCPConfiguration
from wavefront_api_client.models.history_entry import HistoryEntry
from wavefront_api_client.models.history_response import HistoryResponse
from wavefront_api_client.models.ingestion_policy import IngestionPolicy
from wavefront_api_client.models.ingestion_policy_mapping import IngestionPolicyMapping
from wavefront_api_client.models.install_alerts import InstallAlerts
from wavefront_api_client.models.integration import Integration
from wavefront_api_client.models.integration_alert import IntegrationAlert
from wavefront_api_client.models.integration_alias import IntegrationAlias
from wavefront_api_client.models.integration_dashboard import IntegrationDashboard
from wavefront_api_client.models.integration_manifest_group import IntegrationManifestGroup
from wavefront_api_client.models.integration_metrics import IntegrationMetrics
from wavefront_api_client.models.integration_status import IntegrationStatus
from wavefront_api_client.models.json_node import JsonNode
from wavefront_api_client.models.kubernetes_component import KubernetesComponent
from wavefront_api_client.models.kubernetes_component_status import KubernetesComponentStatus
from wavefront_api_client.models.logical_type import LogicalType
from wavefront_api_client.models.maintenance_window import MaintenanceWindow
from wavefront_api_client.models.message import Message
from wavefront_api_client.models.metric_details import MetricDetails
from wavefront_api_client.models.metric_details_response import MetricDetailsResponse
from wavefront_api_client.models.metric_status import MetricStatus
from wavefront_api_client.models.metrics_policy_read_model import MetricsPolicyReadModel
from wavefront_api_client.models.metrics_policy_write_model import MetricsPolicyWriteModel
from wavefront_api_client.models.module import Module
from wavefront_api_client.models.module_descriptor import ModuleDescriptor
from wavefront_api_client.models.module_layer import ModuleLayer
from wavefront_api_client.models.monitored_application_dto import MonitoredApplicationDTO
from wavefront_api_client.models.monitored_cluster import MonitoredCluster
from wavefront_api_client.models.monitored_service_dto import MonitoredServiceDTO
from wavefront_api_client.models.new_relic_configuration import NewRelicConfiguration
from wavefront_api_client.models.new_relic_metric_filters import NewRelicMetricFilters
from wavefront_api_client.models.notificant import Notificant
from wavefront_api_client.models.package import Package
from wavefront_api_client.models.paged import Paged
from wavefront_api_client.models.paged_account import PagedAccount
from wavefront_api_client.models.paged_alert import PagedAlert
from wavefront_api_client.models.paged_alert_with_stats import PagedAlertWithStats
from wavefront_api_client.models.paged_anomaly import PagedAnomaly
from wavefront_api_client.models.paged_cloud_integration import PagedCloudIntegration
from wavefront_api_client.models.paged_customer_facing_user_object import PagedCustomerFacingUserObject
from wavefront_api_client.models.paged_dashboard import PagedDashboard
from wavefront_api_client.models.paged_derived_metric_definition import PagedDerivedMetricDefinition
from wavefront_api_client.models.paged_derived_metric_definition_with_stats import PagedDerivedMetricDefinitionWithStats
from wavefront_api_client.models.paged_event import PagedEvent
from wavefront_api_client.models.paged_external_link import PagedExternalLink
from wavefront_api_client.models.paged_ingestion_policy import PagedIngestionPolicy
from wavefront_api_client.models.paged_integration import PagedIntegration
from wavefront_api_client.models.paged_maintenance_window import PagedMaintenanceWindow
from wavefront_api_client.models.paged_message import PagedMessage
from wavefront_api_client.models.paged_monitored_application_dto import PagedMonitoredApplicationDTO
from wavefront_api_client.models.paged_monitored_cluster import PagedMonitoredCluster
from wavefront_api_client.models.paged_monitored_service_dto import PagedMonitoredServiceDTO
from wavefront_api_client.models.paged_notificant import PagedNotificant
from wavefront_api_client.models.paged_proxy import PagedProxy
from wavefront_api_client.models.paged_related_event import PagedRelatedEvent
from wavefront_api_client.models.paged_report_event_anomaly_dto import PagedReportEventAnomalyDTO
from wavefront_api_client.models.paged_role_dto import PagedRoleDTO
from wavefront_api_client.models.paged_saved_search import PagedSavedSearch
from wavefront_api_client.models.paged_service_account import PagedServiceAccount
from wavefront_api_client.models.paged_source import PagedSource
from wavefront_api_client.models.paged_user_group_model import PagedUserGroupModel
from wavefront_api_client.models.point import Point
from wavefront_api_client.models.policy_rule_read_model import PolicyRuleReadModel
from wavefront_api_client.models.policy_rule_write_model import PolicyRuleWriteModel
from wavefront_api_client.models.proxy import Proxy
from wavefront_api_client.models.query_event import QueryEvent
from wavefront_api_client.models.query_result import QueryResult
from wavefront_api_client.models.query_type_dto import QueryTypeDTO
from wavefront_api_client.models.raw_timeseries import RawTimeseries
from wavefront_api_client.models.related_anomaly import RelatedAnomaly
from wavefront_api_client.models.related_data import RelatedData
from wavefront_api_client.models.related_event import RelatedEvent
from wavefront_api_client.models.related_event_time_range import RelatedEventTimeRange
from wavefront_api_client.models.report_event_anomaly_dto import ReportEventAnomalyDTO
from wavefront_api_client.models.response_container import ResponseContainer
from wavefront_api_client.models.response_container_access_policy import ResponseContainerAccessPolicy
from wavefront_api_client.models.response_container_access_policy_action import ResponseContainerAccessPolicyAction
from wavefront_api_client.models.response_container_account import ResponseContainerAccount
from wavefront_api_client.models.response_container_alert import ResponseContainerAlert
from wavefront_api_client.models.response_container_cloud_integration import ResponseContainerCloudIntegration
from wavefront_api_client.models.response_container_dashboard import ResponseContainerDashboard
from wavefront_api_client.models.response_container_derived_metric_definition import ResponseContainerDerivedMetricDefinition
from wavefront_api_client.models.response_container_event import ResponseContainerEvent
from wavefront_api_client.models.response_container_external_link import ResponseContainerExternalLink
from wavefront_api_client.models.response_container_facet_response import ResponseContainerFacetResponse
from wavefront_api_client.models.response_container_facets_response_container import ResponseContainerFacetsResponseContainer
from wavefront_api_client.models.response_container_history_response import ResponseContainerHistoryResponse
from wavefront_api_client.models.response_container_ingestion_policy import ResponseContainerIngestionPolicy
from wavefront_api_client.models.response_container_integration import ResponseContainerIntegration
from wavefront_api_client.models.response_container_integration_status import ResponseContainerIntegrationStatus
from wavefront_api_client.models.response_container_list_access_control_list_read_dto import ResponseContainerListAccessControlListReadDTO
from wavefront_api_client.models.response_container_list_integration import ResponseContainerListIntegration
from wavefront_api_client.models.response_container_list_integration_manifest_group import ResponseContainerListIntegrationManifestGroup
from wavefront_api_client.models.response_container_list_service_account import ResponseContainerListServiceAccount
from wavefront_api_client.models.response_container_list_string import ResponseContainerListString
from wavefront_api_client.models.response_container_list_user_api_token import ResponseContainerListUserApiToken
from wavefront_api_client.models.response_container_maintenance_window import ResponseContainerMaintenanceWindow
from wavefront_api_client.models.response_container_map_string_integer import ResponseContainerMapStringInteger
from wavefront_api_client.models.response_container_map_string_integration_status import ResponseContainerMapStringIntegrationStatus
from wavefront_api_client.models.response_container_message import ResponseContainerMessage
from wavefront_api_client.models.response_container_metrics_policy_read_model import ResponseContainerMetricsPolicyReadModel
from wavefront_api_client.models.response_container_monitored_application_dto import ResponseContainerMonitoredApplicationDTO
from wavefront_api_client.models.response_container_monitored_cluster import ResponseContainerMonitoredCluster
from wavefront_api_client.models.response_container_monitored_service_dto import ResponseContainerMonitoredServiceDTO
from wavefront_api_client.models.response_container_notificant import ResponseContainerNotificant
from wavefront_api_client.models.response_container_paged_account import ResponseContainerPagedAccount
from wavefront_api_client.models.response_container_paged_alert import ResponseContainerPagedAlert
from wavefront_api_client.models.response_container_paged_alert_with_stats import ResponseContainerPagedAlertWithStats
from wavefront_api_client.models.response_container_paged_anomaly import ResponseContainerPagedAnomaly
from wavefront_api_client.models.response_container_paged_cloud_integration import ResponseContainerPagedCloudIntegration
from wavefront_api_client.models.response_container_paged_customer_facing_user_object import ResponseContainerPagedCustomerFacingUserObject
from wavefront_api_client.models.response_container_paged_dashboard import ResponseContainerPagedDashboard
from wavefront_api_client.models.response_container_paged_derived_metric_definition import ResponseContainerPagedDerivedMetricDefinition
from wavefront_api_client.models.response_container_paged_derived_metric_definition_with_stats import ResponseContainerPagedDerivedMetricDefinitionWithStats
from wavefront_api_client.models.response_container_paged_event import ResponseContainerPagedEvent
from wavefront_api_client.models.response_container_paged_external_link import ResponseContainerPagedExternalLink
from wavefront_api_client.models.response_container_paged_ingestion_policy import ResponseContainerPagedIngestionPolicy
from wavefront_api_client.models.response_container_paged_integration import ResponseContainerPagedIntegration
from wavefront_api_client.models.response_container_paged_maintenance_window import ResponseContainerPagedMaintenanceWindow
from wavefront_api_client.models.response_container_paged_message import ResponseContainerPagedMessage
from wavefront_api_client.models.response_container_paged_monitored_application_dto import ResponseContainerPagedMonitoredApplicationDTO
from wavefront_api_client.models.response_container_paged_monitored_cluster import ResponseContainerPagedMonitoredCluster
from wavefront_api_client.models.response_container_paged_monitored_service_dto import ResponseContainerPagedMonitoredServiceDTO
from wavefront_api_client.models.response_container_paged_notificant import ResponseContainerPagedNotificant
from wavefront_api_client.models.response_container_paged_proxy import ResponseContainerPagedProxy
from wavefront_api_client.models.response_container_paged_related_event import ResponseContainerPagedRelatedEvent
from wavefront_api_client.models.response_container_paged_report_event_anomaly_dto import ResponseContainerPagedReportEventAnomalyDTO
from wavefront_api_client.models.response_container_paged_role_dto import ResponseContainerPagedRoleDTO
from wavefront_api_client.models.response_container_paged_saved_search import ResponseContainerPagedSavedSearch
from wavefront_api_client.models.response_container_paged_service_account import ResponseContainerPagedServiceAccount
from wavefront_api_client.models.response_container_paged_source import ResponseContainerPagedSource
from wavefront_api_client.models.response_container_paged_user_group_model import ResponseContainerPagedUserGroupModel
from wavefront_api_client.models.response_container_proxy import ResponseContainerProxy
from wavefront_api_client.models.response_container_query_type_dto import ResponseContainerQueryTypeDTO
from wavefront_api_client.models.response_container_role_dto import ResponseContainerRoleDTO
from wavefront_api_client.models.response_container_saved_search import ResponseContainerSavedSearch
from wavefront_api_client.models.response_container_service_account import ResponseContainerServiceAccount
from wavefront_api_client.models.response_container_set_business_function import ResponseContainerSetBusinessFunction
from wavefront_api_client.models.response_container_set_source_label_pair import ResponseContainerSetSourceLabelPair
from wavefront_api_client.models.response_container_source import ResponseContainerSource
from wavefront_api_client.models.response_container_string import ResponseContainerString
from wavefront_api_client.models.response_container_tags_response import ResponseContainerTagsResponse
from wavefront_api_client.models.response_container_user_api_token import ResponseContainerUserApiToken
from wavefront_api_client.models.response_container_user_group_model import ResponseContainerUserGroupModel
from wavefront_api_client.models.response_container_validated_users_dto import ResponseContainerValidatedUsersDTO
from wavefront_api_client.models.response_status import ResponseStatus
from wavefront_api_client.models.role_dto import RoleDTO
from wavefront_api_client.models.saved_search import SavedSearch
from wavefront_api_client.models.schema import Schema
from wavefront_api_client.models.search_query import SearchQuery
from wavefront_api_client.models.service_account import ServiceAccount
from wavefront_api_client.models.service_account_write import ServiceAccountWrite
from wavefront_api_client.models.sortable_search_request import SortableSearchRequest
from wavefront_api_client.models.sorting import Sorting
from wavefront_api_client.models.source import Source
from wavefront_api_client.models.source_label_pair import SourceLabelPair
from wavefront_api_client.models.source_search_request_container import SourceSearchRequestContainer
from wavefront_api_client.models.span import Span
from wavefront_api_client.models.specific_data import SpecificData
from wavefront_api_client.models.stats_model_internal_use import StatsModelInternalUse
from wavefront_api_client.models.stripe import Stripe
from wavefront_api_client.models.tags_response import TagsResponse
from wavefront_api_client.models.target_info import TargetInfo
from wavefront_api_client.models.tesla_configuration import TeslaConfiguration
from wavefront_api_client.models.timeseries import Timeseries
from wavefront_api_client.models.trace import Trace
from wavefront_api_client.models.triage_dashboard import TriageDashboard
from wavefront_api_client.models.tuple import Tuple
from wavefront_api_client.models.tuple_result import TupleResult
from wavefront_api_client.models.tuple_value_result import TupleValueResult
from wavefront_api_client.models.user_api_token import UserApiToken
from wavefront_api_client.models.user_dto import UserDTO
from wavefront_api_client.models.user_group import UserGroup
from wavefront_api_client.models.user_group_model import UserGroupModel
from wavefront_api_client.models.user_group_properties_dto import UserGroupPropertiesDTO
from wavefront_api_client.models.user_group_write import UserGroupWrite
from wavefront_api_client.models.user_model import UserModel
from wavefront_api_client.models.user_request_dto import UserRequestDTO
from wavefront_api_client.models.user_to_create import UserToCreate
from wavefront_api_client.models.validated_users_dto import ValidatedUsersDTO
from wavefront_api_client.models.wf_tags import WFTags



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from wavefront_api_client.api_client import ApiClient


class ApiTokenApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_token(self, **kwargs):  # noqa: E501
        """Create new api token  # noqa: E501

        Returns the list of all api tokens for a user. The newly created api token is the last element of returned list.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_token(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ResponseContainerListUserApiToken
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_token_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.create_token_with_http_info(**kwargs)  # noqa: E501
            return data

    def create_token_with_http_info(self, **kwargs):  # noqa: E501
        """Create new api token  # noqa: E501

        Returns the list of all api tokens for a user. The newly created api token is the last element of returned list.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_token_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ResponseContainerListUserApiToken
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_token" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/apitoken', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerListUserApiToken',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_token(self, id, **kwargs):  # noqa: E501
        """Delete the specified api token  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_token(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: ResponseContainerListUserApiToken
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_token_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_token_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def delete_token_with_http_info(self, id, **kwargs):  # noqa: E501
        """Delete the specified api token  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_token_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: ResponseContainerListUserApiToken
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_token" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `delete_token`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/apitoken/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerListUserApiToken',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_token_service_account(self, id, token, **kwargs):  # noqa: E501
        """Delete the specified api token of the given service account  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_token_service_account(id, token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str token: (required)
        :return: ResponseContainerListUserApiToken
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_token_service_account_with_http_info(id, token, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_token_service_account_with_http_info(id, token, **kwargs)  # noqa: E501
            return data

    def delete_token_service_account_with_http_info(self, id, token, **kwargs):  # noqa: E501
        """Delete the specified api token of the given service account  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_token_service_account_with_http_info(id, token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str token: (required)
        :return: ResponseContainerListUserApiToken
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_token_service_account" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `delete_token_service_account`")  # noqa: E501
        # verify the required parameter 'token' is set
        if self.api_client.client_side_validation and ('token' not in params or
                                                       params['token'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `token` when calling `delete_token_service_account`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501
        if 'token' in params:
            path_params['token'] = params['token']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/apitoken/serviceaccount/{id}/{token}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerListUserApiToken',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def generate_token_service_account(self, id, **kwargs):  # noqa: E501
        """Create a new api token for the service account  # noqa: E501

        Returns the list of all api tokens for the service account. The newly created api token is the last element of returned list.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.generate_token_service_account(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param UserApiToken body:
        :return: ResponseContainerListUserApiToken
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.generate_token_service_account_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.generate_token_service_account_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def generate_token_service_account_with_http_info(self, id, **kwargs):  # noqa: E501
        """Create a new api token for the service account  # noqa: E501

        Returns the list of all api tokens for the service account. The newly created api token is the last element of returned list.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.generate_token_service_account_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param UserApiToken body:
        :return: ResponseContainerListUserApiToken
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method generate_token_service_account" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `generate_token_service_account`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/apitoken/serviceaccount/{id}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerListUserApiToken',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_tokens(self, **kwargs):  # noqa: E501
        """Get all api tokens for a user  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_tokens(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ResponseContainerListUserApiToken
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_all_tokens_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_all_tokens_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_all_tokens_with_http_info(self, **kwargs):  # noqa: E501
        """Get all api tokens for a user  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_tokens_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ResponseContainerListUserApiToken
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_tokens" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/apitoken', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerListUserApiToken',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_tokens_service_account(self, id, **kwargs):  # noqa: E501
        """Get all api tokens for the given service account  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_tokens_service_account(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: ResponseContainerListUserApiToken
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_tokens_service_account_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_tokens_service_account_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_tokens_service_account_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get all api tokens for the given service account  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_tokens_service_account_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: ResponseContainerListUserApiToken
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_tokens_service_account" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_tokens_service_account`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/apitoken/serviceaccount/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerListUserApiToken',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_token_name(self, id, **kwargs):  # noqa: E501
        """Update the name of the specified api token  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_token_name(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param UserApiToken body: Example Body:  <pre>{   \"tokenID\": \"Token identifier\",   \"tokenName\": \"Token name\" }</pre>
        :return: ResponseContainerUserApiToken
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_token_name_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_token_name_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def update_token_name_with_http_info(self, id, **kwargs):  # noqa: E501
        """Update the name of the specified api token  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_token_name_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param UserApiToken body: Example Body:  <pre>{   \"tokenID\": \"Token identifier\",   \"tokenName\": \"Token name\" }</pre>
        :return: ResponseContainerUserApiToken
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_token_name" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `update_token_name`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/apitoken/{id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerUserApiToken',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_token_name_service_account(self, id, token, **kwargs):  # noqa: E501
        """Update the name of the specified api token for the given service account  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_token_name_service_account(id, token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str token: (required)
        :param UserApiToken body: Example Body:  <pre>{   \"tokenID\": \"Token identifier\",   \"tokenName\": \"Token name\" }</pre>
        :return: ResponseContainerUserApiToken
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_token_name_service_account_with_http_info(id, token, **kwargs)  # noqa: E501
        else:
            (data) = self.update_token_name_service_account_with_http_info(id, token, **kwargs)  # noqa: E501
            return data

    def update_token_name_service_account_with_http_info(self, id, token, **kwargs):  # noqa: E501
        """Update the name of the specified api token for the given service account  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_token_name_service_account_with_http_info(id, token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str token: (required)
        :param UserApiToken body: Example Body:  <pre>{   \"tokenID\": \"Token identifier\",   \"tokenName\": \"Token name\" }</pre>
        :return: ResponseContainerUserApiToken
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'token', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_token_name_service_account" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `update_token_name_service_account`")  # noqa: E501
        # verify the required parameter 'token' is set
        if self.api_client.client_side_validation and ('token' not in params or
                                                       params['token'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `token` when calling `update_token_name_service_account`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501
        if 'token' in params:
            path_params['token'] = params['token']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/apitoken/serviceaccount/{id}/{token}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerUserApiToken',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class ChartSourceQuery(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'disabled': 'bool',
        'name': 'str',
        'query': 'str',
        'query_type': 'str',
        'querybuilder_enabled': 'bool',
        'querybuilder_serialization': 'str',
        'scatter_plot_source': 'str',
        'secondary_axis': 'bool',
        'source_color': 'str',
        'source_description': 'str'
    }

    attribute_map = {
        'disabled': 'disabled',
        'name': 'name',
        'query': 'query',
        'query_type': 'queryType',
        'querybuilder_enabled': 'querybuilderEnabled',
        'querybuilder_serialization': 'querybuilderSerialization',
        'scatter_plot_source': 'scatterPlotSource',
        'secondary_axis': 'secondaryAxis',
        'source_color': 'sourceColor',
        'source_description': 'sourceDescription'
    }

    def __init__(self, disabled=None, name=None, query=None, query_type=None, querybuilder_enabled=None, querybuilder_serialization=None, scatter_plot_source=None, secondary_axis=None, source_color=None, source_description=None, _configuration=None):  # noqa: E501
        """ChartSourceQuery - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._disabled = None
        self._name = None
        self._query = None
        self._query_type = None
        self._querybuilder_enabled = None
        self._querybuilder_serialization = None
        self._scatter_plot_source = None
        self._secondary_axis = None
        self._source_color = None
        self._source_description = None
        self.discriminator = None

        if disabled is not None:
            self.disabled = disabled
        self.name = name
        self.query = query
        if query_type is not None:
            self.query_type = query_type
        if querybuilder_enabled is not None:
            self.querybuilder_enabled = querybuilder_enabled
        if querybuilder_serialization is not None:
            self.querybuilder_serialization = querybuilder_serialization
        if scatter_plot_source is not None:
            self.scatter_plot_source = scatter_plot_source
        if secondary_axis is not None:
            self.secondary_axis = secondary_axis
        if source_color is not None:
            self.source_color = source_color
        if source_description is not None:
            self.source_description = source_description

    @property
    def disabled(self):
        """Gets the disabled of this ChartSourceQuery.  # noqa: E501

        Whether the source is disabled  # noqa: E501

        :return: The disabled of this ChartSourceQuery.  # noqa: E501
        :rtype: bool
        """
        return self._disabled

    @disabled.setter
    def disabled(self, disabled):
        """Sets the disabled of this ChartSourceQuery.

        Whether the source is disabled  # noqa: E501

        :param disabled: The disabled of this ChartSourceQuery.  # noqa: E501
        :type: bool
        """

        self._disabled = disabled

    @property
    def name(self):
        """Gets the name of this ChartSourceQuery.  # noqa: E501

        Name of the source  # noqa: E501

        :return: The name of this ChartSourceQuery.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ChartSourceQuery.

        Name of the source  # noqa: E501

        :param name: The name of this ChartSourceQuery.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def query(self):
        """Gets the query of this ChartSourceQuery.  # noqa: E501

        Query expression to plot on the chart  # noqa: E501

        :return: The query of this ChartSourceQuery.  # noqa: E501
        :rtype: str
        """
        return self._query

    @query.setter
    def query(self, query):
        """Sets the query of this ChartSourceQuery.

        Query expression to plot on the chart  # noqa: E501

        :param query: The query of this ChartSourceQuery.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and query is None:
            raise ValueError("Invalid value for `query`, must not be `None`")  # noqa: E501

        self._query = query

    @property
    def query_type(self):
        """Gets the query_type of this ChartSourceQuery.  # noqa: E501

        Query type of the source  # noqa: E501

        :return: The query_type of this ChartSourceQuery.  # noqa: E501
        :rtype: str
        """
        return self._query_type

    @query_type.setter
    def query_type(self, query_type):
        """Sets the query_type of this ChartSourceQuery.

        Query type of the source  # noqa: E501

        :param query_type: The query_type of this ChartSourceQuery.  # noqa: E501
        :type: str
        """
        allowed_values = ["WQL", "PROMQL", "HYBRID"]  # noqa: E501
        if (self._configuration.client_side_validation and
                query_type not in allowed_values):
            raise ValueError(
                "Invalid value for `query_type` ({0}), must be one of {1}"  # noqa: E501
                .format(query_type, allowed_values)
            )

        self._query_type = query_type

    @property
    def querybuilder_enabled(self):
        """Gets the querybuilder_enabled of this ChartSourceQuery.  # noqa: E501

        Whether or not this source line should have the query builder enabled  # noqa: E501

        :return: The querybuilder_enabled of this ChartSourceQuery.  # noqa: E501
        :rtype: bool
        """
        return self._querybuilder_enabled

    @querybuilder_enabled.setter
    def querybuilder_enabled(self, querybuilder_enabled):
        """Sets the querybuilder_enabled of this ChartSourceQuery.

        Whether or not this source line should have the query builder enabled  # noqa: E501

        :param querybuilder_enabled: The querybuilder_enabled of this ChartSourceQuery.  # noqa: E501
        :type: bool
        """

        self._querybuilder_enabled = querybuilder_enabled

    @property
    def querybuilder_serialization(self):
        """Gets the querybuilder_serialization of this ChartSourceQuery.  # noqa: E501

        Opaque representation of the querybuilder  # noqa: E501

        :return: The querybuilder_serialization of this ChartSourceQuery.  # noqa: E501
        :rtype: str
        """
        return self._querybuilder_serialization

    @querybuilder_serialization.setter
    def querybuilder_serialization(self, querybuilder_serialization):
        """Sets the querybuilder_serialization of this ChartSourceQuery.

        Opaque representation of the querybuilder  # noqa: E501

        :param querybuilder_serialization: The querybuilder_serialization of this ChartSourceQuery.  # noqa: E501
        :type: str
        """

        self._querybuilder_serialization = querybuilder_serialization

    @property
    def scatter_plot_source(self):
        """Gets the scatter_plot_source of this ChartSourceQuery.  # noqa: E501

        For scatter plots, does this query source the X-axis or the Y-axis  # noqa: E501

        :return: The scatter_plot_source of this ChartSourceQuery.  # noqa: E501
        :rtype: str
        """
        return self._scatter_plot_source

    @scatter_plot_source.setter
    def scatter_plot_source(self, scatter_plot_source):
        """Sets the scatter_plot_source of this ChartSourceQuery.

        For scatter plots, does this query source the X-axis or the Y-axis  # noqa: E501

        :param scatter_plot_source: The scatter_plot_source of this ChartSourceQuery.  # noqa: E501
        :type: str
        """
        allowed_values = ["X", "Y"]  # noqa: E501
        if (self._configuration.client_side_validation and
                scatter_plot_source not in allowed_values):
            raise ValueError(
                "Invalid value for `scatter_plot_source` ({0}), must be one of {1}"  # noqa: E501
                .format(scatter_plot_source, allowed_values)
            )

        self._scatter_plot_source = scatter_plot_source

    @property
    def secondary_axis(self):
        """Gets the secondary_axis of this ChartSourceQuery.  # noqa: E501

        Determines if this source relates to the right hand Y-axis or not  # noqa: E501

        :return: The secondary_axis of this ChartSourceQuery.  # noqa: E501
        :rtype: bool
        """
        return self._secondary_axis

    @secondary_axis.setter
    def secondary_axis(self, secondary_axis):
        """Sets the secondary_axis of this ChartSourceQuery.

        Determines if this source relates to the right hand Y-axis or not  # noqa: E501

        :param secondary_axis: The secondary_axis of this ChartSourceQuery.  # noqa: E501
        :type: bool
        """

        self._secondary_axis = secondary_axis

    @property
    def source_color(self):
        """Gets the source_color of this ChartSourceQuery.  # noqa: E501

        The color used to draw all results from this source (auto if unset)  # noqa: E501

        :return: The source_color of this ChartSourceQuery.  # noqa: E501
        :rtype: str
        """
        return self._source_color

    @source_color.setter
    def source_color(self, source_color):
        """Sets the source_color of this ChartSourceQuery.

        The color used to draw all results from this source (auto if unset)  # noqa: E501

        :param source_color: The source_color of this ChartSourceQuery.  # noqa: E501
        :type: str
        """

        self._source_color = source_color

    @property
    def source_description(self):
        """Gets the source_description of this ChartSourceQuery.  # noqa: E501

        A description for the purpose of this source  # noqa: E501

        :return: The source_description of this ChartSourceQuery.  # noqa: E501
        :rtype: str
        """
        return self._source_description

    @source_description.setter
    def source_description(self, source_description):
        """Sets the source_description of this ChartSourceQuery.

        A description for the purpose of this source  # noqa: E501

        :param source_description: The source_description of this ChartSourceQuery.  # noqa: E501
        :type: str
        """

        self._source_description = source_description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ChartSourceQuery, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChartSourceQuery):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ChartSourceQuery):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from wavefront_api_client.api.access_policy_api import AccessPolicyApi
from wavefront_api_client.api.account__user_and_service_account_api import AccountUserAndServiceAccountApi
from wavefront_api_client.api.alert_api import AlertApi
from wavefront_api_client.api.api_token_api import ApiTokenApi
from wavefront_api_client.api.cloud_integration_api import CloudIntegrationApi
from wavefront_api_client.api.dashboard_api import DashboardApi
from wavefront_api_client.api.derived_metric_api import DerivedMetricApi
from wavefront_api_client.api.direct_ingestion_api import DirectIngestionApi
from wavefront_api_client.api.event_api import EventApi
from wavefront_api_client.api.external_link_api import ExternalLinkApi
from wavefront_api_client.api.ingestion_spy_api import IngestionSpyApi
from wavefront_api_client.api.integration_api import IntegrationApi
from wavefront_api_client.api.maintenance_window_api import MaintenanceWindowApi
from wavefront_api_client.api.message_api import MessageApi
from wavefront_api_client.api.metric_api import MetricApi
from wavefront_api_client.api.metrics_policy_api import MetricsPolicyApi
from wavefront_api_client.api.monitored_application_api import MonitoredApplicationApi
from wavefront_api_client.api.monitored_service_api import MonitoredServiceApi
from wavefront_api_client.api.notificant_api import NotificantApi
from wavefront_api_client.api.proxy_api import ProxyApi
from wavefront_api_client.api.query_api import QueryApi
from wavefront_api_client.api.role_api import RoleApi
from wavefront_api_client.api.saved_search_api import SavedSearchApi
from wavefront_api_client.api.search_api import SearchApi
from wavefront_api_client.api.source_api import SourceApi
from wavefront_api_client.api.usage_api import UsageApi
from wavefront_api_client.api.user_api import UserApi
from wavefront_api_client.api.user_group_api import UserGroupApi
from wavefront_api_client.api.webhook_api import WebhookApi



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import wavefront_api_client
from wavefront_api_client.api.source_api import SourceApi  # noqa: E501
from wavefront_api_client.rest import ApiException


class TestSourceApi(unittest.TestCase):
    """SourceApi unit test stubs"""

    def setUp(self):
        self.api = wavefront_api_client.api.source_api.SourceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_source_tag(self):
        """Test case for add_source_tag

        Add a tag to a specific source  # noqa: E501
        """
        pass

    def test_create_source(self):
        """Test case for create_source

        Create metadata (description or tags) for a specific source  # noqa: E501
        """
        pass

    def test_delete_source(self):
        """Test case for delete_source

        Delete metadata (description and tags) for a specific source  # noqa: E501
        """
        pass

    def test_get_all_source(self):
        """Test case for get_all_source

        Get all sources for a customer  # noqa: E501
        """
        pass

    def test_get_source(self):
        """Test case for get_source

        Get a specific source for a customer  # noqa: E501
        """
        pass

    def test_get_source_tags(self):
        """Test case for get_source_tags

        Get all tags associated with a specific source  # noqa: E501
        """
        pass

    def test_remove_description(self):
        """Test case for remove_description

        Remove description from a specific source  # noqa: E501
        """
        pass

    def test_remove_source_tag(self):
        """Test case for remove_source_tag

        Remove a tag from a specific source  # noqa: E501
        """
        pass

    def test_set_description(self):
        """Test case for set_description

        Set description associated with a specific source  # noqa: E501
        """
        pass

    def test_set_source_tags(self):
        """Test case for set_source_tags

        Set all tags associated with a specific source  # noqa: E501
        """
        pass

    def test_update_source(self):
        """Test case for update_source

        Update metadata (description or tags) for a specific source.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class IntegrationMetrics(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'chart_objs': 'list[Chart]',
        'charts': 'list[str]',
        'display': 'list[str]',
        'pps_dimensions': 'list[str]',
        'prefixes': 'list[str]',
        'required': 'list[str]'
    }

    attribute_map = {
        'chart_objs': 'chartObjs',
        'charts': 'charts',
        'display': 'display',
        'pps_dimensions': 'ppsDimensions',
        'prefixes': 'prefixes',
        'required': 'required'
    }

    def __init__(self, chart_objs=None, charts=None, display=None, pps_dimensions=None, prefixes=None, required=None, _configuration=None):  # noqa: E501
        """IntegrationMetrics - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._chart_objs = None
        self._charts = None
        self._display = None
        self._pps_dimensions = None
        self._prefixes = None
        self._required = None
        self.discriminator = None

        if chart_objs is not None:
            self.chart_objs = chart_objs
        self.charts = charts
        self.display = display
        if pps_dimensions is not None:
            self.pps_dimensions = pps_dimensions
        self.prefixes = prefixes
        self.required = required

    @property
    def chart_objs(self):
        """Gets the chart_objs of this IntegrationMetrics.  # noqa: E501

        Chart JSONs materialized from the links in `charts`  # noqa: E501

        :return: The chart_objs of this IntegrationMetrics.  # noqa: E501
        :rtype: list[Chart]
        """
        return self._chart_objs

    @chart_objs.setter
    def chart_objs(self, chart_objs):
        """Sets the chart_objs of this IntegrationMetrics.

        Chart JSONs materialized from the links in `charts`  # noqa: E501

        :param chart_objs: The chart_objs of this IntegrationMetrics.  # noqa: E501
        :type: list[Chart]
        """

        self._chart_objs = chart_objs

    @property
    def charts(self):
        """Gets the charts of this IntegrationMetrics.  # noqa: E501

        URLs for JSON definitions of charts that display info about this integration's metrics  # noqa: E501

        :return: The charts of this IntegrationMetrics.  # noqa: E501
        :rtype: list[str]
        """
        return self._charts

    @charts.setter
    def charts(self, charts):
        """Sets the charts of this IntegrationMetrics.

        URLs for JSON definitions of charts that display info about this integration's metrics  # noqa: E501

        :param charts: The charts of this IntegrationMetrics.  # noqa: E501
        :type: list[str]
        """
        if self._configuration.client_side_validation and charts is None:
            raise ValueError("Invalid value for `charts`, must not be `None`")  # noqa: E501

        self._charts = charts

    @property
    def display(self):
        """Gets the display of this IntegrationMetrics.  # noqa: E501

        Set of metrics that are displayed in the metric panel during integration setup  # noqa: E501

        :return: The display of this IntegrationMetrics.  # noqa: E501
        :rtype: list[str]
        """
        return self._display

    @display.setter
    def display(self, display):
        """Sets the display of this IntegrationMetrics.

        Set of metrics that are displayed in the metric panel during integration setup  # noqa: E501

        :param display: The display of this IntegrationMetrics.  # noqa: E501
        :type: list[str]
        """
        if self._configuration.client_side_validation and display is None:
            raise ValueError("Invalid value for `display`, must not be `None`")  # noqa: E501

        self._display = display

    @property
    def pps_dimensions(self):
        """Gets the pps_dimensions of this IntegrationMetrics.  # noqa: E501

        For reported points belonging to this integration, these point tags are escalated to the internal point-rate counters so that reporting can be broken out by these dimensions  # noqa: E501

        :return: The pps_dimensions of this IntegrationMetrics.  # noqa: E501
        :rtype: list[str]
        """
        return self._pps_dimensions

    @pps_dimensions.setter
    def pps_dimensions(self, pps_dimensions):
        """Sets the pps_dimensions of this IntegrationMetrics.

        For reported points belonging to this integration, these point tags are escalated to the internal point-rate counters so that reporting can be broken out by these dimensions  # noqa: E501

        :param pps_dimensions: The pps_dimensions of this IntegrationMetrics.  # noqa: E501
        :type: list[str]
        """

        self._pps_dimensions = pps_dimensions

    @property
    def prefixes(self):
        """Gets the prefixes of this IntegrationMetrics.  # noqa: E501

        Set of metric prefix namespaces belonging to this integration  # noqa: E501

        :return: The prefixes of this IntegrationMetrics.  # noqa: E501
        :rtype: list[str]
        """
        return self._prefixes

    @prefixes.setter
    def prefixes(self, prefixes):
        """Sets the prefixes of this IntegrationMetrics.

        Set of metric prefix namespaces belonging to this integration  # noqa: E501

        :param prefixes: The prefixes of this IntegrationMetrics.  # noqa: E501
        :type: list[str]
        """
        if self._configuration.client_side_validation and prefixes is None:
            raise ValueError("Invalid value for `prefixes`, must not be `None`")  # noqa: E501

        self._prefixes = prefixes

    @property
    def required(self):
        """Gets the required of this IntegrationMetrics.  # noqa: E501

        Set of \"canary\" metrics that define the \"liveness\" of this integration's metric ingestion  # noqa: E501

        :return: The required of this IntegrationMetrics.  # noqa: E501
        :rtype: list[str]
        """
        return self._required

    @required.setter
    def required(self, required):
        """Sets the required of this IntegrationMetrics.

        Set of \"canary\" metrics that define the \"liveness\" of this integration's metric ingestion  # noqa: E501

        :param required: The required of this IntegrationMetrics.  # noqa: E501
        :type: list[str]
        """
        if self._configuration.client_side_validation and required is None:
            raise ValueError("Invalid value for `required`, must not be `None`")  # noqa: E501

        self._required = required

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IntegrationMetrics, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IntegrationMetrics):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, IntegrationMetrics):
            return True

        return self.to_dict() != other.to_dict()
